==> nextcloud-23.0.12p1.tgz: nextcloud/apps/support/l10n/sk.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Odkaz:",
    "Password:" : "Heslo:",
    "Generating system report failed." : "Nepodarilo sa vygenerovať systémový report.",
    "Could not create folder \"System information\" to store generated report." : "Nepodarilo sa vytvoriť priečinok \"System information\" na uloženie vygenerovaného reportu.",
    "Could not create file \"%s\" to store generated report." : "Nepodarilo sa vytvoriť súbor \"%s\" na uloženie vygenerovaného reportu.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "Súbor „%s“ sa nepodarilo zdieľať. Nájdete ho však v priečinku „Systémové informácie“.",
    "Subscription notifications" : "Notifikácie predplatného",
    "Nextcloud Subscription" : "Nextcloud predplatné",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Váš server nemá Nextcloud predplatné alebo predplatné vypršalo.",
    "Your Nextcloud server subscription does not cover your number of users." : "Vaše Nextcloud predplatné nepokrýva Váš počet používateľov.",
    "Your Nextcloud Subscription has expired!" : "Platnosť vášho predplatného pre Nextcloud vypršala!",
    "Your server has no Nextcloud Subscription" : "Váš server nemá žiadne predplatné Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Váš server Nextcloud nie je podporovaný predplatným Nextcloud Enterprise.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Predplatné spoločnosti Nextcloud Enterprise znamená, že pôvodní vývojári vášho cloudového servera s vlastným hosťovaním sú 100% oddaní vášmu úspechu: bezpečnosť, škálovateľnosť, výkon a funkčnosť vašej služby!",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Ak prestane fungovať nastavenie servera a zamestnanci už nemôžu pracovať, nemusíte sa spoliehať na hľadanie riešenia online fór. Máte priamy prístup k našim skúseným inžinierom!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Máte s dodávateľom zmluvu o poskytovaní včasných bezpečnostných informácií, znížení rizika, opravy a aktualizácie.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Ak potrebujete zostať trochu dlhšie v aktuálnej verzii bez vyrušovania, nemusíte prevádzkovať softvér bez aktualizácií zabezpečenia.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Máte po ruke najlepšie odborné znalosti na riešenie problémov s výkonom a škálovateľnosťou.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Máte prístup k správnej dokumentácii a odborným znalostiam, pomocou ktorých môžete rýchlo odpovedať na otázky súvisiace s dodržiavaním predpisov alebo plniť požiadavky GDPR, HIPAA a ďalšie regulačné požiadavky.",
    "A subscription helps you get the most out of Nextcloud!" : "Predplatné vám pomôže vyťažiť z Nextcloud maximum!",
    "Learn more now" : "Viac informácií",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Táto správa bola pomocou aplikácie Podpora odoslaná všetkým správcom  vo vašej inštancii Nextcloud na %1$s, pretože máte cez %2$sregistrovaných používateľov.",
    "Your Nextcloud server Subscription is over limit" : "Vaše predplatné servera Nextcloud prekračuje limit",
    "Dear admin," : "Vážený administrátor,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Vaše predplatné Nextcloud nezahŕňa počet používateľov, ktorí sú aktuálne na tomto serveri. Ak chcete aktualizovať svoje predplatné, kontaktujte svojho obchodníka v Nextcloude!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s je správca vášho účtu a môžete sa naňho obrátiť e-mailom %2$s alebo telefonicky %3$s.",
    "Thank you," : "Ďakujeme,",
    "Your Nextcloud team" : "Váš tím Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Tento e-mail bol aplikáciou Podpora poslaný všetkým správcom vašej inštancie Nexcloudu v %s pretože máte viac používateľov, ako kryje vaše predplatné.",
    "Your Nextcloud server Subscription is expired" : "Platnosť predplatného vášho servera Nextcloud skončila",
    "Your Nextcloud server Subscription is expired!" : "Platnosť predplatného vášho servera Nextcloud skončila!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Platnosť vášho predplatného Nextcloud vypršala! Ak chcete aktualizovať svoje predplatné, kontaktujte svojho obchodníka v Nextcloud!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Tento e-mail poslala aplikácia Podpora všetkým administrátorom vo vašej inštancii Nextcloud na %s, pretože platnosť vášho predplatného skončila.",
    "Support" : "Podpora",
    "Getting support and help for your Nextcloud" : "Získanie podpory a pomoci pre váš Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Aplikácia Podpora vám poskytuje priamy prístup k zdrojom pomoci a konzultáciám, vyhradené možnosti kontaktovania obchodníka a prehľad podnikového predplatného.",
    "Basic subscription" : "Základné predplatné",
    "Standard subscription" : "Štandardné predplatné",
    "Premium subscription" : "Prémiové predplatné",
    "Géant subscription" : "Predplatné Géant",
    "Silver partner subscription" : "Predplatné strieborného partnera",
    "Gold partner subscription" : "Predplatné zlatého partnera",
    "Subscription" : "Predplatné",
    "Over subscription limit" : "Prekročený limit predplatného",
    "Valid subscription" : "Platné predplatné",
    "Expired subscription" : "Platnosť predplatného skončila",
    "Subscription key:" : "Kľúč predplatného:",
    "Expires in: " : "Platnosť končí:",
    "_%n year_::_%n years_" : ["%n rok","%n roky","%n roky","%n rokov"],
    "_%n month_::_%n months_" : ["%n mesiac","%n mesiace","%n mesiace","%n mesiacov"],
    "_%n week_::_%n weeks_" : ["%n týždeň","%n týždne","%n týždne","%n týždňov"],
    "_%n day_::_%n days_" : ["%n deň","%n dni","%ndni","%n dní"],
    "For an unlimited amount of users" : "Pre neobmedzené množstvo používateľov",
    "_For %n active users_::_For %n active users_" : ["Pre %n aktívneho používateľa","Pre %n aktívnych používateľov","Pre %n aktívnych používateľov","Pre %n aktívnych používateľov"],
    "_For %n users_::_For %n users_" : ["Pre %n používateľa","Pre %n používateľov","Pre %n používateľov","Pre %n používateľov"],
    "_currently at %n user_::_currently at %n users_" : ["momentálne na %n používateľa","momentálne na %n používateľov","momentálne na %n používateľov","momentálne na %n používateľov"],
    "Includes support for %s" : "Zahŕňa podporu pre %s",
    "Includes support for %1$s & %2$s" : "Zahŕňa podporu pre %1$s a %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Zahŕňa podporu pre %1$s, %2$s a %3$s",
    "Extended maintenance life cycle" : "Predĺžená doba údržby",
    "Update subscription key" : "Aktualizovať kľúč predplatného",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s je váš obchodník. Ak máte otázky týkajúce sa predplatného, neváhajte nás kontaktovať.",
    "You can find answers to common question in our portal and also file support requests there." : "Odpovede na bežné otázky nájdete na našom portáli a tiež tam nájdete žiadosti o podporu.",
    "Access Nextcloud portal" : "Prístup na portál Nextcloud",
    "System information" : "Systémové informácie",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Zhrnúť systémové informácie pre technickú podporu. Tlačidlo nižšie vygeneruje textový súbor v priečinku „Systémové informácie“ a zdieľa ho ako verejný odkaz chránený heslom. Odkaz je platný 2 týždne.",
    "Generate system report" : "Vytvoriť správu o systéme",
    "Enterprise subscription recommended" : "Odporúča sa predplatné pre podniky",
    "No active enterprise subscription" : "Žiadne aktívne predplatné pre podniky",
    "Unsupported" : "Nepodporované",
    "This Nextcloud server has no Enterprise Subscription." : "Tento server Nextcloud nemá žiadne predplatné Enterprise.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Predplatné Nextcloud Enterprise vám pomôže vyťažiť maximum zo služby Nextcloud, zaistiť bezpečnosť vašich údajov a server pracúci spoľahlivo za všetkých okolností.",
    "Advantages" : "Výhody",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Prístup k technickým znalostiam vývojárov Nextcloud prostredníctvom dokumentácie a podpory",
    "Access to additional capabilities like Outlook integration, online office and more" : "Prístup k ďalším funkciám, ako je integrácia programu Outlook, online kancelária a ďalšie",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Prístup expertíze a škálovateľnosti pre Súbory a Hovory",
    "Optional branding, consulting, architecture advice" : "Voliteľne vytvorenie firemného vzhľadu, poradenstvo, poradenstvo v oblasti architektúry",
    "Confidential security notification service, mitigations, patches and advice" : "Služba pre dôverné upozorňovanie na chyby zabezpečení, zníženie rizika jich zneužitia, opravy a odporúčania",
    "Compliance certification, advice and documentation" : "Osvedčenie o zhode, poradenstvo a dokumentácia",
    "Get a quote" : "Požiadať ponuku",
    "More information" : "Viac informácií",
    "Subscription benefits" : "Výhody predplatného",
    "Pricing" : "Cenník",
    "Community support" : "Podpora komunity",
    "Forum" : "Fórum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud je slobodný softvér, ktorý podporuje veľmi aktívna komunita. Ak chcete klásť otázky a diskutovať s ostatnými, zaregistrujte sa na fóre.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud používa GitHub ako platformu pre spoluprácu. Hlásenia o chybách môžete zadávať priamo tam.",
    "Chat" : "Správy",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Porozprávajte sa s nami na našom IRC kanále #nextcloud na Freenode.",
    "Nextcloud forum" : "Fórum Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud na GitHub",
    "Open chat" : "Otvoriť rozhovor",
    "Subscription key" : "Kľúč predplatného",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Ak máte aktívne predplatné Nextcloud, sem zadajte jeho kľúč.",
    "Learn more about an enterprise subscription." : "Viac informácií o predplatnom pre podniky.",
    "Set subscription key" : "Nastaviť kľúč predplatného",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Momentálne se nedarí správne získať informácie o predplatnom. Je naplánovaný opätovný pokus. Pozrite se tu neskôr.",
    "The subscription key was invalid." : "Kľúč predplatného bol neplatný.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Kľúč na odber sa nepodarilo overiť, pretože tento server nemá pripojenie na internet. Ak to chcete vyriešiť, kontaktujte tím podpory.",
    "The subscription key had an invalid format." : "Kľúč na odber mal neplatný formát.",
    "While fetching the subscription information an error happened." : "Pri načítavaní informácií o predplatnom sa vyskytla chyba.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Tlačidlo nižšie vytvorí textový súbor v priečinku „Systémové informácie“ a zdieľa ho ako verejný odkaz chránený heslom. Odkaz je platný 2 týždne.",
    "News" : "Správy",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Ak chcete získať aktuálne informácie o dianí v Nextcloud, prihláste sa na odber bulletinu a sledujte nás na sociálnych sietiach.",
    "Like our Facebook page" : "Sleduj nás na Facebook-u",
    "Follow us on Twitter" : "Sleduj nás na Twitter-i",
    "Check out our blog" : "Pozri si náš blog",
    "Subscribe to our newsletter" : "Prihlás sa na odber noviniek emailom"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/support/l10n/sk.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Odkaz:",
    "Password:" : "Heslo:",
    "Generating system report failed." : "Nepodarilo sa vygenerovať systémový report.",
    "Could not create folder \"System information\" to store generated report." : "Nepodarilo sa vytvoriť priečinok \"System information\" na uloženie vygenerovaného reportu.",
    "Could not create file \"%s\" to store generated report." : "Nepodarilo sa vytvoriť súbor \"%s\" na uloženie vygenerovaného reportu.",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "Súbor „%s“ sa nepodarilo zdieľať. Nájdete ho však v priečinku „Systémové informácie“.",
    "Subscription notifications" : "Odoberané upozornenia",
    "Nextcloud Subscription" : "Nextcloud predplatné",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Váš server nemá Nextcloud predplatné alebo predplatné vypršalo.",
    "Your Nextcloud server subscription does not cover your number of users." : "Vaše Nextcloud predplatné nepokrýva Váš počet používateľov.",
    "Your Nextcloud Subscription has expired!" : "Platnosť vášho predplatného pre Nextcloud vypršala!",
    "Your server has no Nextcloud Subscription" : "Váš server nemá žiadne predplatné Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Váš server Nextcloud nie je podporovaný predplatným Nextcloud Enterprise.",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Ak prestane fungovať nastavenie servera a zamestnanci už nemôžu pracovať, nemusíte sa spoliehať na hľadanie riešenia online fór. Máte priamy prístup k našim skúseným inžinierom!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Máte s dodávateľom zmluvu o poskytovaní včasných bezpečnostných informácií, znížení rizika, opravy a aktualizácie.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Ak potrebujete zostať trochu dlhšie v aktuálnej verzii bez vyrušovania, nemusíte prevádzkovať softvér bez aktualizácií zabezpečenia.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Máte po ruke najlepšie odborné znalosti na riešenie problémov s výkonom a škálovateľnosťou.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Máte prístup k správnej dokumentácii a odborným znalostiam, pomocou ktorých môžete rýchlo odpovedať na otázky súvisiace s dodržiavaním predpisov alebo plniť požiadavky GDPR, HIPAA a ďalšie regulačné požiadavky.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "Môžeme tiež poskytnúť integráciu Outlook, Online Office, škálovateľnú integrovanú audio-video a chatovú komunikáciu a ďalšie funkcie dostupné iba v obmedzenej forme zadarmo alebo rozvíjať ďalšie integrácie a vlastnosti podľa vašich potrieb.",
    "A subscription helps you get the most out of Nextcloud!" : "Predplatné vám pomôže vyťažiť z Nextcloud maximum!",
    "Learn more now" : "Viac informácií",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Táto správa bola pomocou aplikácie Podpora odoslaná všetkým správcom  vo vašej inštancii Nextcloud na %1$s, pretože máte cez %2$sregistrovaných používateľov.",
    "Your Nextcloud server Subscription is over limit" : "Vaše predplatné servera Nextcloud prekračuje limit",
    "Dear admin," : "Vážený administrátor,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Vaše predplatné Nextcloud nezahŕňa počet používateľov, ktorí sú aktuálne na tomto serveri. Ak chcete aktualizovať svoje predplatné, kontaktujte svojho obchodníka v Nextcloude!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s je správca vášho účtu a môžete sa naňho obrátiť e-mailom %2$s alebo telefonicky %3$s.",
    "Thank you," : "Ďakujeme,",
    "Your Nextcloud team" : "Váš tím Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Tento e-mail bol aplikáciou Podpora poslaný všetkým správcom vašej inštancie Nexcloudu v %s pretože máte viac používateľov, ako kryje vaše predplatné.",
    "Your Nextcloud server Subscription is expired" : "Platnosť predplatného vášho servera Nextcloud skončila",
    "Your Nextcloud server Subscription is expired!" : "Platnosť predplatného vášho servera Nextcloud skončila!",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Platnosť vášho predplatného Nextcloud vypršala! Ak chcete aktualizovať svoje predplatné, kontaktujte svojho obchodníka v Nextcloud!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Tento e-mail poslala aplikácia Podpora všetkým administrátorom vo vašej inštancii Nextcloud na %s, pretože platnosť vášho predplatného skončila.",
    "Support" : "Podpora",
    "Getting support and help for your Nextcloud" : "Získanie podpory a pomoci pre váš Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Aplikácia Podpora vám poskytuje priamy prístup k zdrojom pomoci a konzultáciám, vyhradené možnosti kontaktovania obchodníka a prehľad podnikového predplatného.",
    "Basic subscription" : "Základné predplatné",
    "Standard subscription" : "Štandardné predplatné",
    "Premium subscription" : "Prémiové predplatné",
    "Géant subscription" : "Predplatné Géant",
    "Silver partner subscription" : "Predplatné strieborného partnera",
    "Gold partner subscription" : "Predplatné zlatého partnera",
    "Subscription" : "Predplatné",
    "Over subscription limit" : "Prekročený limit predplatného",
    "Valid subscription" : "Platné predplatné",
    "Expired subscription" : "Platnosť predplatného skončila",
    "Subscription key:" : "Kľúč predplatného:",
    "Expires in: " : "Platnosť končí:",
    "_%n year_::_%n years_" : ["%n rok","%n roky","%n roky","%n rokov"],
    "_%n month_::_%n months_" : ["%n mesiac","%n mesiace","%n mesiace","%n mesiacov"],
    "_%n week_::_%n weeks_" : ["%n týždeň","%n týždne","%n týždne","%n týždňov"],
    "_%n day_::_%n days_" : ["%n deň","%n dni","%ndni","%n dní"],
    "For an unlimited amount of users" : "Pre neobmedzené množstvo používateľov",
    "_For %n active users_::_For %n active users_" : ["Pre %n aktívneho používateľa","Pre %n aktívnych používateľov","Pre %n aktívnych používateľov","Pre %n aktívnych používateľov"],
    "_For %n users_::_For %n users_" : ["Pre %n používateľa","Pre %n používateľov","Pre %n používateľov","Pre %n používateľov"],
    "_currently at %n user_::_currently at %n users_" : ["momentálne na %n používateľa","momentálne na %n používateľov","momentálne na %n používateľov","momentálne na %n používateľov"],
    "Includes support for %s" : "Zahŕňa podporu pre %s",
    "Includes support for %1$s & %2$s" : "Zahŕňa podporu pre %1$s a %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Zahŕňa podporu pre %1$s, %2$s a %3$s",
    "Extended maintenance life cycle" : "Predĺžená doba údržby",
    "Update subscription key" : "Aktualizovať kľúč predplatného",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s je váš obchodník. Ak máte otázky týkajúce sa predplatného, neváhajte nás kontaktovať.",
    "You can find answers to common question in our portal and also file support requests there." : "Odpovede na bežné otázky nájdete na našom portáli a tiež tam nájdete žiadosti o podporu.",
    "Access Nextcloud portal" : "Prístup na portál Nextcloud",
    "System information" : "Systémové informácie",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Zhrnúť systémové informácie pre technickú podporu. Tlačidlo nižšie vygeneruje textový súbor v priečinku „Systémové informácie“ a zdieľa ho ako verejný odkaz chránený heslom. Odkaz je platný 2 týždne.",
    "Generate system report" : "Vytvoriť správu o systéme",
    "Enterprise subscription recommended" : "Odporúča sa predplatné pre podniky",
    "No active enterprise subscription" : "Žiadne aktívne predplatné pre podniky",
    "Unsupported" : "Nepodporované",
    "This Nextcloud server has no Enterprise Subscription." : "Tento server Nextcloud nemá žiadne predplatné Enterprise.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Predplatné Nextcloud Enterprise vám pomôže vyťažiť maximum zo služby Nextcloud, zaistiť bezpečnosť vašich údajov a server pracúci spoľahlivo za všetkých okolností.",
    "Advantages" : "Výhody",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Prístup k technickým znalostiam vývojárov Nextcloud prostredníctvom dokumentácie a podpory",
    "Access to additional capabilities like Outlook integration, online office and more" : "Prístup k ďalším funkciám, ako je integrácia programu Outlook, online kancelária a ďalšie",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Prístup expertíze a škálovateľnosti pre Súbory a Hovory",
    "Optional branding, consulting, architecture advice" : "Voliteľne vytvorenie firemného vzhľadu, poradenstvo, poradenstvo v oblasti architektúry",
    "Confidential security notification service, mitigations, patches and advice" : "Služba pre dôverné upozorňovanie na chyby zabezpečení, zníženie rizika jich zneužitia, opravy a odporúčania",
    "Compliance certification, advice and documentation" : "Osvedčenie o zhode, poradenstvo a dokumentácia",
    "Get a quote" : "Požiadať ponuku",
    "More information" : "Viac informácií",
    "Subscription benefits" : "Výhody predplatného",
    "Pricing" : "Cenník",
    "Community support" : "Podpora komunity",
    "Forum" : "Fórum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud je slobodný softvér, ktorý podporuje veľmi aktívna komunita. Ak chcete klásť otázky a diskutovať s ostatnými, zaregistrujte sa na fóre.",
    "Nextcloud forum" : "Fórum Nextcloud",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud používa GitHub ako platformu pre spoluprácu. Hlásenia o chybách môžete zadávať priamo tam.",
    "Nextcloud at GitHub" : "Nextcloud na GitHub",
    "Subscription key" : "Kľúč predplatného",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Ak máte aktívne predplatné Nextcloud, sem zadajte jeho kľúč.",
    "Learn more about an enterprise subscription." : "Viac informácií o predplatnom pre podniky.",
    "Set subscription key" : "Nastaviť kľúč predplatného",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Momentálne se nedarí správne získať informácie o predplatnom. Je naplánovaný opätovný pokus. Pozrite se tu neskôr.",
    "The subscription key was invalid." : "Kľúč predplatného bol neplatný.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Kľúč na odber sa nepodarilo overiť, pretože tento server nemá pripojenie na internet. Ak to chcete vyriešiť, kontaktujte tím podpory.",
    "The subscription key had an invalid format." : "Kľúč na odber mal neplatný formát.",
    "While fetching the subscription information an error happened." : "Pri načítavaní informácií o predplatnom sa vyskytla chyba.",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Tlačidlo nižšie vytvorí textový súbor v priečinku „Systémové informácie“ a zdieľa ho ako verejný odkaz chránený heslom. Odkaz je platný 2 týždne.",
    "News" : "Správy",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Ak chcete získať aktuálne informácie o dianí v Nextcloud, prihláste sa na odber bulletinu a sledujte nás na sociálnych sietiach.",
    "Like our Facebook page" : "Sleduj nás na Facebook-u",
    "Follow us on Twitter" : "Sleduj nás na Twitter-i",
    "Check out our blog" : "Pozri si náš blog",
    "Subscribe to our newsletter" : "Prihlás sa na odber noviniek emailom"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
